# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RegistryModelInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'model_path': 'RegistryModelPathInfo',
        'hugging_face': 'RegistryHuggingFaceModelInfo',
        'generative_language_model': 'RegistryGenerativeLanguageModelInfo'
    }

    attribute_map = {
        'model_path': 'modelPath',
        'hugging_face': 'huggingFace',
        'generative_language_model': 'generativeLanguageModel'
    }

    def __init__(self, model_path=None, hugging_face=None, generative_language_model=None):  # noqa: E501
        """RegistryModelInfo - a model defined in Swagger"""  # noqa: E501
        self._model_path = None
        self._hugging_face = None
        self._generative_language_model = None
        self.discriminator = None
        if model_path is not None:
            self.model_path = model_path
        if hugging_face is not None:
            self.hugging_face = hugging_face
        if generative_language_model is not None:
            self.generative_language_model = generative_language_model

    @property
    def model_path(self):
        """Gets the model_path of this RegistryModelInfo.  # noqa: E501


        :return: The model_path of this RegistryModelInfo.  # noqa: E501
        :rtype: RegistryModelPathInfo
        """
        return self._model_path

    @model_path.setter
    def model_path(self, model_path):
        """Sets the model_path of this RegistryModelInfo.


        :param model_path: The model_path of this RegistryModelInfo.  # noqa: E501
        :type: RegistryModelPathInfo
        """

        self._model_path = model_path

    @property
    def hugging_face(self):
        """Gets the hugging_face of this RegistryModelInfo.  # noqa: E501


        :return: The hugging_face of this RegistryModelInfo.  # noqa: E501
        :rtype: RegistryHuggingFaceModelInfo
        """
        return self._hugging_face

    @hugging_face.setter
    def hugging_face(self, hugging_face):
        """Sets the hugging_face of this RegistryModelInfo.


        :param hugging_face: The hugging_face of this RegistryModelInfo.  # noqa: E501
        :type: RegistryHuggingFaceModelInfo
        """

        self._hugging_face = hugging_face

    @property
    def generative_language_model(self):
        """Gets the generative_language_model of this RegistryModelInfo.  # noqa: E501


        :return: The generative_language_model of this RegistryModelInfo.  # noqa: E501
        :rtype: RegistryGenerativeLanguageModelInfo
        """
        return self._generative_language_model

    @generative_language_model.setter
    def generative_language_model(self, generative_language_model):
        """Sets the generative_language_model of this RegistryModelInfo.


        :param generative_language_model: The generative_language_model of this RegistryModelInfo.  # noqa: E501
        :type: RegistryGenerativeLanguageModelInfo
        """

        self._generative_language_model = generative_language_model

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RegistryModelInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistryModelInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
