# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NotificationNotification(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'RimeUUID',
        'object_type': 'NotificationObjectType',
        'object_id': 'str',
        'notification_type': 'NotificationNotificationType',
        'config': 'SchemanotificationConfig',
        'webhooks': 'list[NotificationWebhookConfig]',
        'emails': 'list[str]',
        'last_send_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'object_type': 'objectType',
        'object_id': 'objectId',
        'notification_type': 'notificationType',
        'config': 'config',
        'webhooks': 'webhooks',
        'emails': 'emails',
        'last_send_time': 'lastSendTime'
    }

    def __init__(self, id=None, object_type=None, object_id=None, notification_type=None, config=None, webhooks=None, emails=None, last_send_time=None):  # noqa: E501
        """NotificationNotification - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._object_type = None
        self._object_id = None
        self._notification_type = None
        self._config = None
        self._webhooks = None
        self._emails = None
        self._last_send_time = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if object_type is not None:
            self.object_type = object_type
        if object_id is not None:
            self.object_id = object_id
        if notification_type is not None:
            self.notification_type = notification_type
        if config is not None:
            self.config = config
        if webhooks is not None:
            self.webhooks = webhooks
        if emails is not None:
            self.emails = emails
        if last_send_time is not None:
            self.last_send_time = last_send_time

    @property
    def id(self):
        """Gets the id of this NotificationNotification.  # noqa: E501


        :return: The id of this NotificationNotification.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this NotificationNotification.


        :param id: The id of this NotificationNotification.  # noqa: E501
        :type: RimeUUID
        """

        self._id = id

    @property
    def object_type(self):
        """Gets the object_type of this NotificationNotification.  # noqa: E501


        :return: The object_type of this NotificationNotification.  # noqa: E501
        :rtype: NotificationObjectType
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this NotificationNotification.


        :param object_type: The object_type of this NotificationNotification.  # noqa: E501
        :type: NotificationObjectType
        """

        self._object_type = object_type

    @property
    def object_id(self):
        """Gets the object_id of this NotificationNotification.  # noqa: E501

        Uniquely specifies the object for the notification.  # noqa: E501

        :return: The object_id of this NotificationNotification.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this NotificationNotification.

        Uniquely specifies the object for the notification.  # noqa: E501

        :param object_id: The object_id of this NotificationNotification.  # noqa: E501
        :type: str
        """

        self._object_id = object_id

    @property
    def notification_type(self):
        """Gets the notification_type of this NotificationNotification.  # noqa: E501


        :return: The notification_type of this NotificationNotification.  # noqa: E501
        :rtype: NotificationNotificationType
        """
        return self._notification_type

    @notification_type.setter
    def notification_type(self, notification_type):
        """Sets the notification_type of this NotificationNotification.


        :param notification_type: The notification_type of this NotificationNotification.  # noqa: E501
        :type: NotificationNotificationType
        """

        self._notification_type = notification_type

    @property
    def config(self):
        """Gets the config of this NotificationNotification.  # noqa: E501


        :return: The config of this NotificationNotification.  # noqa: E501
        :rtype: SchemanotificationConfig
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this NotificationNotification.


        :param config: The config of this NotificationNotification.  # noqa: E501
        :type: SchemanotificationConfig
        """

        self._config = config

    @property
    def webhooks(self):
        """Gets the webhooks of this NotificationNotification.  # noqa: E501

        Webhooks are a list of destination webhooks to which notifications will be sent.  # noqa: E501

        :return: The webhooks of this NotificationNotification.  # noqa: E501
        :rtype: list[NotificationWebhookConfig]
        """
        return self._webhooks

    @webhooks.setter
    def webhooks(self, webhooks):
        """Sets the webhooks of this NotificationNotification.

        Webhooks are a list of destination webhooks to which notifications will be sent.  # noqa: E501

        :param webhooks: The webhooks of this NotificationNotification.  # noqa: E501
        :type: list[NotificationWebhookConfig]
        """

        self._webhooks = webhooks

    @property
    def emails(self):
        """Gets the emails of this NotificationNotification.  # noqa: E501

        Emails specify the list of emails to which notifications will be sent.  # noqa: E501

        :return: The emails of this NotificationNotification.  # noqa: E501
        :rtype: list[str]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """Sets the emails of this NotificationNotification.

        Emails specify the list of emails to which notifications will be sent.  # noqa: E501

        :param emails: The emails of this NotificationNotification.  # noqa: E501
        :type: list[str]
        """

        self._emails = emails

    @property
    def last_send_time(self):
        """Gets the last_send_time of this NotificationNotification.  # noqa: E501

        Last send time is the last time the notification was successfully sent.  # noqa: E501

        :return: The last_send_time of this NotificationNotification.  # noqa: E501
        :rtype: datetime
        """
        return self._last_send_time

    @last_send_time.setter
    def last_send_time(self, last_send_time):
        """Sets the last_send_time of this NotificationNotification.

        Last send time is the last time the notification was successfully sent.  # noqa: E501

        :param last_send_time: The last_send_time of this NotificationNotification.  # noqa: E501
        :type: datetime
        """

        self._last_send_time = last_send_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotificationNotification, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationNotification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
