# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativefirewallFirewallConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fact_sheet_url': 'str',
        'sensitive_terms_url': 'str',
        'topic': 'str'
    }

    attribute_map = {
        'fact_sheet_url': 'factSheetUrl',
        'sensitive_terms_url': 'sensitiveTermsUrl',
        'topic': 'topic'
    }

    def __init__(self, fact_sheet_url=None, sensitive_terms_url=None, topic=None):  # noqa: E501
        """GenerativefirewallFirewallConfig - a model defined in Swagger"""  # noqa: E501
        self._fact_sheet_url = None
        self._sensitive_terms_url = None
        self._topic = None
        self.discriminator = None
        if fact_sheet_url is not None:
            self.fact_sheet_url = fact_sheet_url
        if sensitive_terms_url is not None:
            self.sensitive_terms_url = sensitive_terms_url
        if topic is not None:
            self.topic = topic

    @property
    def fact_sheet_url(self):
        """Gets the fact_sheet_url of this GenerativefirewallFirewallConfig.  # noqa: E501

        Fact sheet URL describes the location of a fact sheet to use in validation rules around correctness. If not provided, the factual inconsistency rules will not run.  # noqa: E501

        :return: The fact_sheet_url of this GenerativefirewallFirewallConfig.  # noqa: E501
        :rtype: str
        """
        return self._fact_sheet_url

    @fact_sheet_url.setter
    def fact_sheet_url(self, fact_sheet_url):
        """Sets the fact_sheet_url of this GenerativefirewallFirewallConfig.

        Fact sheet URL describes the location of a fact sheet to use in validation rules around correctness. If not provided, the factual inconsistency rules will not run.  # noqa: E501

        :param fact_sheet_url: The fact_sheet_url of this GenerativefirewallFirewallConfig.  # noqa: E501
        :type: str
        """

        self._fact_sheet_url = fact_sheet_url

    @property
    def sensitive_terms_url(self):
        """Gets the sensitive_terms_url of this GenerativefirewallFirewallConfig.  # noqa: E501

        Sensitive terms URL describes the location of a sensitive terms sheet to use in validation rules around PII. If not provided, the PII rules will not run.  # noqa: E501

        :return: The sensitive_terms_url of this GenerativefirewallFirewallConfig.  # noqa: E501
        :rtype: str
        """
        return self._sensitive_terms_url

    @sensitive_terms_url.setter
    def sensitive_terms_url(self, sensitive_terms_url):
        """Sets the sensitive_terms_url of this GenerativefirewallFirewallConfig.

        Sensitive terms URL describes the location of a sensitive terms sheet to use in validation rules around PII. If not provided, the PII rules will not run.  # noqa: E501

        :param sensitive_terms_url: The sensitive_terms_url of this GenerativefirewallFirewallConfig.  # noqa: E501
        :type: str
        """

        self._sensitive_terms_url = sensitive_terms_url

    @property
    def topic(self):
        """Gets the topic of this GenerativefirewallFirewallConfig.  # noqa: E501

        Topic describes the expected chat topic. It is used for the Off-topic rule. Example: \"question answering about the US Bureau of Labor Statistics jobs report\" If not provided, the off-topic rule will not run.  # noqa: E501

        :return: The topic of this GenerativefirewallFirewallConfig.  # noqa: E501
        :rtype: str
        """
        return self._topic

    @topic.setter
    def topic(self, topic):
        """Sets the topic of this GenerativefirewallFirewallConfig.

        Topic describes the expected chat topic. It is used for the Off-topic rule. Example: \"question answering about the US Bureau of Labor Statistics jobs report\" If not provided, the off-topic rule will not run.  # noqa: E501

        :param topic: The topic of this GenerativefirewallFirewallConfig.  # noqa: E501
        :type: str
        """

        self._topic = topic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativefirewallFirewallConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativefirewallFirewallConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
