# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DatacollectorDatapointRow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'input_data': 'str',
        'label': 'str',
        'timestamp': 'datetime',
        'query_id': 'str'
    }

    attribute_map = {
        'input_data': 'inputData',
        'label': 'label',
        'timestamp': 'timestamp',
        'query_id': 'queryId'
    }

    def __init__(self, input_data=None, label=None, timestamp=None, query_id=None):  # noqa: E501
        """DatacollectorDatapointRow - a model defined in Swagger"""  # noqa: E501
        self._input_data = None
        self._label = None
        self._timestamp = None
        self._query_id = None
        self.discriminator = None
        if input_data is not None:
            self.input_data = input_data
        if label is not None:
            self.label = label
        if timestamp is not None:
            self.timestamp = timestamp
        if query_id is not None:
            self.query_id = query_id

    @property
    def input_data(self):
        """Gets the input_data of this DatacollectorDatapointRow.  # noqa: E501


        :return: The input_data of this DatacollectorDatapointRow.  # noqa: E501
        :rtype: str
        """
        return self._input_data

    @input_data.setter
    def input_data(self, input_data):
        """Sets the input_data of this DatacollectorDatapointRow.


        :param input_data: The input_data of this DatacollectorDatapointRow.  # noqa: E501
        :type: str
        """

        self._input_data = input_data

    @property
    def label(self):
        """Gets the label of this DatacollectorDatapointRow.  # noqa: E501


        :return: The label of this DatacollectorDatapointRow.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this DatacollectorDatapointRow.


        :param label: The label of this DatacollectorDatapointRow.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def timestamp(self):
        """Gets the timestamp of this DatacollectorDatapointRow.  # noqa: E501

        If timestamp is not provided in request, the time when the datapoint is stored will be used.  # noqa: E501

        :return: The timestamp of this DatacollectorDatapointRow.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this DatacollectorDatapointRow.

        If timestamp is not provided in request, the time when the datapoint is stored will be used.  # noqa: E501

        :param timestamp: The timestamp of this DatacollectorDatapointRow.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    @property
    def query_id(self):
        """Gets the query_id of this DatacollectorDatapointRow.  # noqa: E501

        Query ID is required for Ranking model tasks.  # noqa: E501

        :return: The query_id of this DatacollectorDatapointRow.  # noqa: E501
        :rtype: str
        """
        return self._query_id

    @query_id.setter
    def query_id(self, query_id):
        """Sets the query_id of this DatacollectorDatapointRow.

        Query ID is required for Ranking model tasks.  # noqa: E501

        :param query_id: The query_id of this DatacollectorDatapointRow.  # noqa: E501
        :type: str
        """

        self._query_id = query_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DatacollectorDatapointRow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DatacollectorDatapointRow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
